==> distribution-5.50.0.zip: drr/regulation/esma/emir/refit/trade/validation/DeliveryReportValidator.java <==
package drr.regulation.esma.emir.refit.trade.validation;

import cdm.base.staticdata.asset.common.ISOCurrencyCodeEnum;
import com.google.common.collect.Lists;
import com.rosetta.model.lib.expression.ComparisonResult;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.records.Date;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.Validator;
import drr.regulation.esma.emir.refit.trade.DeliveryReport;
import iso20022.auth030.esma.DurationType1Code;
import iso20022.auth030.esma.EnergyQuantityUnit2Code;
import java.math.BigDecimal;
import java.time.LocalTime;
import java.util.List;

import static com.google.common.base.Strings.isNullOrEmpty;
import static com.rosetta.model.lib.expression.ExpressionOperators.checkCardinality;
import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;
import static java.util.stream.Collectors.toList;

public class DeliveryReportValidator implements Validator<DeliveryReport> {

	private List<ComparisonResult> getComparisonResults(DeliveryReport o) {
		return Lists.<ComparisonResult>newArrayList(
				checkCardinality("deliveryStartTime", (LocalTime) o.getDeliveryStartTime() != null ? 1 : 0, 0, 1), 
				checkCardinality("deliveryEndTime", (LocalTime) o.getDeliveryEndTime() != null ? 1 : 0, 0, 1), 
				checkCardinality("deliveryStartDate", (Date) o.getDeliveryStartDate() != null ? 1 : 0, 0, 1), 
				checkCardinality("deliveryEndDate", (Date) o.getDeliveryEndDate() != null ? 1 : 0, 0, 1), 
				checkCardinality("duration", (DurationType1Code) o.getDuration() != null ? 1 : 0, 0, 1), 
				checkCardinality("deliveryCapacity", (BigDecimal) o.getDeliveryCapacity() != null ? 1 : 0, 0, 1), 
				checkCardinality("quantityUnit", (EnergyQuantityUnit2Code) o.getQuantityUnit() != null ? 1 : 0, 0, 1), 
				checkCardinality("priceTimeIntervalQuantity", (BigDecimal) o.getPriceTimeIntervalQuantity() != null ? 1 : 0, 0, 1), 
				checkCardinality("currencyOfThePriceTimeIntervalQuantity", (ISOCurrencyCodeEnum) o.getCurrencyOfThePriceTimeIntervalQuantity() != null ? 1 : 0, 0, 1)
			);
	}

	@Override
	public List<ValidationResult<?>> getValidationResults(RosettaPath path, DeliveryReport o) {
		return getComparisonResults(o)
			.stream()
			.map(res -> {
				if (!isNullOrEmpty(res.getError())) {
					return failure("DeliveryReport", ValidationResult.ValidationType.CARDINALITY, "DeliveryReport", path, "", res.getError());
				}
				return success("DeliveryReport", ValidationResult.ValidationType.CARDINALITY, "DeliveryReport", path, "");
			})
			.collect(toList());
	}

}

==> distribution-5.55.0.zip: drr/regulation/esma/emir/refit/trade/validation/DeliveryReportValidator.java <==
package drr.regulation.esma.emir.refit.trade.validation;

import cdm.base.staticdata.asset.common.ISOCurrencyCodeEnum;
import com.google.common.collect.Lists;
import com.rosetta.model.lib.expression.ComparisonResult;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.records.Date;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.Validator;
import drr.regulation.esma.emir.refit.trade.DeliveryReport;
import iso20022.auth030.esma.DurationType1Code;
import iso20022.auth030.esma.EnergyQuantityUnit2Code;
import java.math.BigDecimal;
import java.time.LocalTime;
import java.util.List;

import static com.google.common.base.Strings.isNullOrEmpty;
import static com.rosetta.model.lib.expression.ExpressionOperatorsNullSafe.checkCardinality;
import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;
import static java.util.stream.Collectors.toList;

public class DeliveryReportValidator implements Validator<DeliveryReport> {

	private List<ComparisonResult> getComparisonResults(DeliveryReport o) {
		return Lists.<ComparisonResult>newArrayList(
				checkCardinality("deliveryStartTime", (LocalTime) o.getDeliveryStartTime() != null ? 1 : 0, 0, 1), 
				checkCardinality("deliveryEndTime", (LocalTime) o.getDeliveryEndTime() != null ? 1 : 0, 0, 1), 
				checkCardinality("deliveryStartDate", (Date) o.getDeliveryStartDate() != null ? 1 : 0, 0, 1), 
				checkCardinality("deliveryEndDate", (Date) o.getDeliveryEndDate() != null ? 1 : 0, 0, 1), 
				checkCardinality("duration", (DurationType1Code) o.getDuration() != null ? 1 : 0, 0, 1), 
				checkCardinality("deliveryCapacity", (BigDecimal) o.getDeliveryCapacity() != null ? 1 : 0, 0, 1), 
				checkCardinality("quantityUnit", (EnergyQuantityUnit2Code) o.getQuantityUnit() != null ? 1 : 0, 0, 1), 
				checkCardinality("priceTimeIntervalQuantity", (BigDecimal) o.getPriceTimeIntervalQuantity() != null ? 1 : 0, 0, 1), 
				checkCardinality("currencyOfThePriceTimeIntervalQuantity", (ISOCurrencyCodeEnum) o.getCurrencyOfThePriceTimeIntervalQuantity() != null ? 1 : 0, 0, 1)
			);
	}

	@Override
	public List<ValidationResult<?>> getValidationResults(RosettaPath path, DeliveryReport o) {
		return getComparisonResults(o)
			.stream()
			.map(res -> {
				if (!isNullOrEmpty(res.getError())) {
					return failure("DeliveryReport", ValidationResult.ValidationType.CARDINALITY, "DeliveryReport", path, "", res.getError());
				}
				return success("DeliveryReport", ValidationResult.ValidationType.CARDINALITY, "DeliveryReport", path, "");
			})
			.collect(toList());
	}

}
